KashidaPoint class

A point where a kashida may be inserted.

Constructors

KashidaPoint({required int index, required int priority})
Creates a point after grapheme cluster index with priority 0–9.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
index int
The grapheme cluster index the kashida goes after.
final
priority int
The kashida point priority, from 0–9. Higher is more preferable.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

endOffsetIn(String text) int
UTF-16 offset in text after this grapheme, for substring.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override