KashidaWord class

A word on a justified line, with kashida slots into text.

Constructors

KashidaWord({required String text, required List<KashidaPoint> points})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
Word text (after optional tatweel stripping), without fill tatweels.
final

Methods

elongated() String
text with the chosen number of tatweels inserted.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited