KashidaWord class
A word on a justified line, with kashida slots into text.
Constructors
-
KashidaWord({required String text, required List<
KashidaPoint> points})
Properties
Methods
-
elongated(
) → String - text with the chosen number of tatweels inserted.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited